@@ -2,7 +2,6 @@
     a CSV or from another calculation in the project.
 '''
 
-from collections import namedtuple
 from contextlib import suppress
 import numpy as np
 
@@ -10,9 +9,9 @@ from PyQt5 import QtWidgets, QtCore
 from matplotlib.figure import Figure
 from matplotlib.backends.backend_qt5agg import FigureCanvasQTAgg as FigureCanvas
 
-from .. import output
-from .. import distributions
-from .. import dataset
+from ..common import plotting, distributions
+from ..datasets import dataset
+from ..project import ProjectDataSet
 from . import page_csvload
 from . import configmgr
 from . import gui_common
@@ -29,6 +28,11 @@ class ProjectTreeDelegate(QtWidgets.QItemDelegate):
 
 class ProjectTreeDists(QtWidgets.QTreeWidget):
     ''' Tree Widget showing all project items with usable distributions '''
+    # NOTE: ROLE_DDATA item.data stores a tuple (distdictionary,)
+    # because Qt attempts to cast a plain dict to QVariant which
+    # messes up order and makes a new object. It doesn't attempt to cast
+    # the tuple or its contents.
+
     ROLE_DDATA = QtCore.Qt.UserRole
     loaddata = QtCore.pyqtSignal(object)  # Emit the data array or dictionary
 
@@ -46,12 +50,12 @@ class ProjectTreeDists(QtWidgets.QTreeWidget):
             for i in range(self.project.count()):
                 mode = self.project.get_mode(i)
                 if mode in ['uncertainty', 'reverse', 'curvefit', 'data']:
-                    with suppress(AttributeError):
-                        distdict = self.project.items[i].get_output().get_dists()  # Pass no args to get names
+                    with suppress(AttributeError):  # AttributeError if calculation has not run
+                        distdict = self.project.items[i].get_dists()
                         item = QtWidgets.QTreeWidgetItem([names[i]])
                         item.setIcon(0, gui_common.load_icon(gui_common.iconname[mode]))
                         self.addTopLevelItem(item)
-                        item.setData(0, self.ROLE_DDATA, distdict)
+                        item.setData(0, self.ROLE_DDATA, (distdict,))  # tuple containing distdict
 
         item = QtWidgets.QTreeWidgetItem(['Select CSV File...'])
         item.setIcon(0, gui_common.load_icon('table'))
@@ -75,15 +79,14 @@ class ProjectTreeDists(QtWidgets.QTreeWidget):
                 if dlg.exec_():
                     self.csvitems.append(dlg.dataset())
                     # DataSets loaded from CSV in this dialog
-                    datadict = self.csvitems[-1].get_output().get_dists()
+                    datadict = self.csvitems[-1].get_dists()
                     item = QtWidgets.QTreeWidgetItem([f'CSV Data {len(self.csvitems)+1}'])
                     item.setIcon(0, gui_common.load_icon(gui_common.iconname['data']))
-                    item.setData(0, self.ROLE_DDATA, datadict)
+                    item.setData(0, self.ROLE_DDATA, (datadict,))   # tuple containing distdict
                     self.addTopLevelItem(item)
                     self.loaddata.emit(datadict)
-
         else:
-            datadict = item.data(0, self.ROLE_DDATA)
+            datadict, = item.data(0, self.ROLE_DDATA)   # extract tuple containing distdict
             self.loaddata.emit(datadict)
 
 
@@ -114,7 +117,7 @@ class ProjectTreeArrays(QtWidgets.QTreeWidget):
                 mode = self.project.get_mode(i)
                 if mode in ['sweep', 'reversesweep', 'data']:
                     with suppress(AttributeError):
-                        dsets = self.project.items[i].get_output().get_dataset()  # No args to get names
+                        dsets = self.project.items[i].get_dataset()  # No args to get names
                         item = QtWidgets.QTreeWidgetItem([names[i]])
                         item.setIcon(0, gui_common.load_icon(gui_common.iconname[mode]))
                         self.addTopLevelItem(item)
@@ -149,8 +152,8 @@ class ProjectTreeArrays(QtWidgets.QTreeWidget):
                 dlg = page_csvload.SelectCSVData(fname)
                 if dlg.exec_():
                     self.csvitems.append(dlg.dataset())
-                    # DataSets loaded from CSV in this dialog
-                    dists = self.csvitems[-1].get_output().get_dataset()
+                    # ProjectDataSets loaded from CSV in this dialog
+                    dists = self.csvitems[-1].get_dataset()
                     item = QtWidgets.QTreeWidgetItem([f'CSV Data {len(self.csvitems)+1}'])
                     item.setIcon(0, gui_common.load_icon(gui_common.iconname['data']))
                     self.addTopLevelItem(item)
@@ -162,12 +165,12 @@ class ProjectTreeArrays(QtWidgets.QTreeWidget):
                         item.addChild(distitem)
                         item.setExpanded(True)
                     self.setCurrentItem(item)
-                    self.loaddata.emit(self.csvitems[-1])
+                    self.loaddata.emit(self.csvitems[-1].model)
 
         else:
             calc = item.data(0, self.ROLE_CALC)
             with suppress(AttributeError):  # Could be top-level item
-                data = calc.get_output().get_dataset(item.data(0, self.ROLE_NAME))
+                data = calc.get_dataset(item.data(0, self.ROLE_NAME))
                 self.loaddata.emit(data)
 
 
@@ -183,6 +186,9 @@ class DistributionSelectWidget(QtWidgets.QDialog):
 
     def __init__(self, project=None, singlecol=True, coloptions=None, enablecorr=True, parent=None):
         super().__init__(parent=parent)
+        font = self.font()
+        font.setPointSize(10)
+        self.setFont(font)
         self.project = project
         self.singlecol = singlecol
         gui_widgets.centerWindow(self, 1000, 800)
@@ -193,7 +199,8 @@ class DistributionSelectWidget(QtWidgets.QDialog):
         self.dataset = None  # Either DataSet object or a dictionary defining mean/std/df for each column?
 
         dists = settings.getDistributions()
-        dists = ['normal (standard error)', 'normal (with autocorrelation)'] + [d for d in dists if distributions.fittable(d)]
+        dists = ['normal (standard error)',
+                 'normal (with autocorrelation)'] + [d for d in dists if distributions.fittable(d)]
         self.treeSource = ProjectTreeDists(project=project)
         self.fig = Figure()
         self.canvas = FigureCanvas(self.fig)
@@ -214,7 +221,8 @@ class DistributionSelectWidget(QtWidgets.QDialog):
         self.lblX = QtWidgets.QLabel('X Value')
         self.table = QtWidgets.QTableWidget()
         self.table.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectColumns)
-        self.lblAssign = QtWidgets.QLabel('<font color="red">Please assign at least one variable before continuing.</font>')
+        self.lblAssign = QtWidgets.QLabel(
+            '<font color="red">Please assign at least one variable before continuing.</font>')
         self.dlgbutton = QtWidgets.QDialogButtonBox(QtWidgets.QDialogButtonBox.Ok | QtWidgets.QDialogButtonBox.Cancel)
 
         if coloptions is not None:
@@ -236,7 +244,7 @@ class DistributionSelectWidget(QtWidgets.QDialog):
         hlayout = QtWidgets.QHBoxLayout()
         hlayout.addWidget(self.lblCol)
         hlayout.addWidget(self.cmbColumn)
-        hlayout.addStretch
+        hlayout.addStretch()
         hlayout.addWidget(self.lblDist)
         hlayout.addWidget(self.cmbDistType)
         hlayout.addWidget(self.lblX)
@@ -278,7 +286,7 @@ class DistributionSelectWidget(QtWidgets.QDialog):
     def get_selcolname(self):
         ''' Get selected column name '''
         col = self.table.currentColumn()
-        if col is not None:
+        if col is not None and col < len(self.colnames):
             col = self.colnames[col]
         return col
 
@@ -301,18 +309,20 @@ class DistributionSelectWidget(QtWidgets.QDialog):
                 samples = data['samples']
                 distname = self.cmbDistType.currentText()
                 if distname == 'normal (standard error)':
-                    params = {'median': np.median(data['samples']), 'std': data['samples'].std(ddof=1)/np.sqrt(len(data['samples']))}
+                    params = {'median': np.median(data['samples']),
+                              'std': data['samples'].std(ddof=1)/np.sqrt(len(data['samples']))}
                     fitdist = distributions.get_distribution('normal', **params)
 
                 elif distname == 'normal (with autocorrelation)':
-                    params = {'median': np.median(data['samples']), 'std': dataset.uncert_autocorrelated(data['samples']).uncert}
+                    params = {'median': np.median(data['samples']),
+                              'std': dataset.uncert_autocorrelated(data['samples']).uncert}
                     fitdist = distributions.get_distribution('normal', **params)
 
                 else:
                     fitdist = distributions.get_distribution(distname)
                     params = fitdist.fit(samples)
                 if self.chkProbPlot.isChecked() and distname != 'histogram':
-                    output.probplot(samples, ax=ax, sparams=params, dist=fitdist.dist.name)
+                    plotting.probplot(samples, ax=ax, sparams=params, dist=fitdist.dist.name)
                 else:
                     xx = np.linspace(samples.min(), samples.max(), num=200)
                     yy = fitdist.pdf(xx)
@@ -342,7 +352,8 @@ class DistributionSelectWidget(QtWidgets.QDialog):
 
     def _get_colassignment(self):
         ''' Get list of variable names for each column '''
-        return [self.table.horizontalHeaderItem(i).text() if self.table.horizontalHeaderItem(i) else '' for i in range(self.table.columnCount())]
+        return [self.table.horizontalHeaderItem(i).text() if self.table.horizontalHeaderItem(i) else ''
+                for i in range(self.table.columnCount())]
 
     def disttypechanged(self):
         ''' Distribution assignment has changed '''
@@ -356,7 +367,7 @@ class DistributionSelectWidget(QtWidgets.QDialog):
         ''' Column assignment has changed '''
         varname = self.cmbColumn.currentText()
         varlist = self._get_colassignment()
-        if varname == 'Not used' or varname == '':
+        if varname in ['Not Used', '']:
             self.table.setHorizontalHeaderItem(self.table.currentColumn(), QtWidgets.QTableWidgetItem(''))
         else:
             if varname in varlist:
@@ -366,7 +377,7 @@ class DistributionSelectWidget(QtWidgets.QDialog):
 
         if self.singlecol and len(self._get_colassignment()) > 0:
             self.dlgbutton.button(QtWidgets.QDialogButtonBox.Ok).setEnabled(True)
-        elif all([col == 'Not Used' or col == '' for col in self._get_colassignment()]):
+        elif all([col in ('Not Used', '') for col in self._get_colassignment()]):
             self.lblAssign.setVisible(True)
             self.dlgbutton.button(QtWidgets.QDialogButtonBox.Ok).setEnabled(False)
         else:
@@ -374,7 +385,7 @@ class DistributionSelectWidget(QtWidgets.QDialog):
             self.dlgbutton.button(QtWidgets.QDialogButtonBox.Ok).setEnabled(True)
 
         for cidx, colname in enumerate(self._get_colassignment()):
-            if colname != '' and colname != 'Not Used':
+            if colname not in ('', 'Not Used'):
                 colcolor = gui_common.COLOR_SELECTED
             else:
                 colcolor = gui_common.COLOR_OK
@@ -434,16 +445,14 @@ class DistributionSelectWidget(QtWidgets.QDialog):
                 std = params.get('std')
                 df = params.get('df')
                 sem = std / np.sqrt(df+1)
-                self.table.setItem(self.ROW_MEAN, cidx, gui_widgets.ReadOnlyTableItem(format(mean, '.4g')))
-                self.table.setItem(self.ROW_STD, cidx, gui_widgets.ReadOnlyTableItem(format(std, '.4g')))
-                self.table.setItem(self.ROW_SEM, cidx, gui_widgets.ReadOnlyTableItem(format(sem, '.4g')))
-                self.table.setItem(self.ROW_DF, cidx, gui_widgets.ReadOnlyTableItem(format(df, '.0f')))
+                self.table.setItem(self.ROW_MEAN, cidx, gui_widgets.ReadOnlyTableItem(f'{mean:.4g}'))
+                self.table.setItem(self.ROW_STD, cidx, gui_widgets.ReadOnlyTableItem(f'{std:.4g}'))
+                self.table.setItem(self.ROW_SEM, cidx, gui_widgets.ReadOnlyTableItem(f'{sem:.4g}'))
+                self.table.setItem(self.ROW_DF, cidx, gui_widgets.ReadOnlyTableItem(f'{df:.0f}'))
         self.updateplot()
 
     def get_dist(self):
-        ''' Get dictionary of distributions assigned
-
-        '''
+        ''' Get dictionary of distributions assigned '''
         distlist = []
         if self.singlecol:
             colname = self.get_selcolname()
@@ -464,10 +473,12 @@ class DistributionSelectWidget(QtWidgets.QDialog):
             if 'samples' in data:
                 if distname == 'normal (standard error)':
                     distname = 'normal'
-                    params = {'median': np.mean(data['samples']), 'std': data['samples'].std(ddof=1)/np.sqrt(len(data['samples']))}
+                    params = {'median': np.mean(data['samples']),
+                              'std': data['samples'].std(ddof=1)/np.sqrt(len(data['samples']))}
 
                 elif distname == 'normal (with autocorrelation)':
-                    params = {'median': np.mean(data['samples']), 'std': dataset.uncert_autocorrelated(data['samples']).uncert}
+                    params = {'median': np.mean(data['samples']),
+                              'std': dataset.uncert_autocorrelated(data['samples']).uncert}
                     distname = 'normal'
 
                 else:
@@ -488,7 +499,7 @@ class DistributionSelectWidget(QtWidgets.QDialog):
                 else:
                     x = self.xval.value()
                 params = f(x)
-            elif 'sem' in data and distname == 'normal (standard error)':
+            elif 'sem' in data:
                 params = {'dist': 'normal',
                           'median': data.get('median', data.get('mean', 0)),
                           'std': data.get('sem'),
@@ -506,7 +517,7 @@ class DistributionSelectWidget(QtWidgets.QDialog):
                     name1, name2 = distlist[i][0], distlist[j][0]
                     data1, data2 = distlist[i][2].get('samples'), distlist[j][2].get('samples')
                     with suppress(TypeError, ValueError):  # Could have one of the datas not be sampled values
-                        corrdict[(name1, name2)] = np.corrcoef(data1, data2)[0, 1]
+                        corrdict[(name1, name2)] = np.nan_to_num(np.corrcoef(data1, data2)[0, 1])
             dists['_correlation_'] = corrdict
 
         if self.singlecol:
@@ -537,7 +548,7 @@ class DistributionSelectWidget(QtWidgets.QDialog):
                 params = f(x)
                 mean = params.get('mean', 0)
                 std = params.get('std', 1)
-                df = data.get('df', 100)
+                df = params.get('df', 100)
                 sem = std / np.sqrt(df + 1)
                 dist = ''  # Can't change this dist
             elif 'samples' in data:
@@ -546,24 +557,18 @@ class DistributionSelectWidget(QtWidgets.QDialog):
                 df = len(data['samples']) - 1
                 sem = std / np.sqrt(df + 1)
                 dist = 'normal (standard error)'
-            elif 'sem' in data:
-                mean = data.get('mean', data.get('median', 0))
-                std = data.get('std', 1)
-                sem = data.get('sem')
-                df = data.get('df', 100)
-                dist = 'normal (standard error)'
             else:
                 mean = data.get('mean', 0)
-                std = data.get('std', 1)
+                std = data.get('std', np.nan)
                 df = data.get('df', 100)
-                sem = std / np.sqrt(df + 1)
+                sem = data.get('sem', std / np.sqrt(df + 1))
                 dist = ''  # Can't change this dist
 
             self.table.setItem(self.ROW_NAME, col, gui_widgets.ReadOnlyTableItem(name))
-            self.table.setItem(self.ROW_MEAN, col, gui_widgets.ReadOnlyTableItem(format(mean, '.2g')))
-            self.table.setItem(self.ROW_STD, col, gui_widgets.ReadOnlyTableItem(format(std, '.2g')))
-            self.table.setItem(self.ROW_SEM, col, gui_widgets.ReadOnlyTableItem(format(sem, '.2g')))
-            self.table.setItem(self.ROW_DF, col, gui_widgets.ReadOnlyTableItem(format(df, '.0f')))
+            self.table.setItem(self.ROW_MEAN, col, gui_widgets.ReadOnlyTableItem(f'{mean:.2g}'))
+            self.table.setItem(self.ROW_STD, col, gui_widgets.ReadOnlyTableItem(f'{std:.2g}'))
+            self.table.setItem(self.ROW_SEM, col, gui_widgets.ReadOnlyTableItem(f'{sem:.2g}'))
+            self.table.setItem(self.ROW_DF, col, gui_widgets.ReadOnlyTableItem(f'{df:.0f}'))
             self.table.setItem(self.ROW_DIST, col, gui_widgets.ReadOnlyTableItem(dist))
             if self.coloptions is not None and name in self.coloptions:
                 hdr.append(name)
@@ -581,19 +586,24 @@ class ArraySelectWidget(QtWidgets.QDialog):
     ''' Widget for selecting an array of values from the project or a file '''
     def __init__(self, project=None, singlecol=False, colnames=None, parent=None):
         super().__init__(parent=parent)
+        font = self.font()
+        font.setPointSize(10)
+        self.setFont(font)
         self.project = project
         self.singlecol = singlecol
         gui_widgets.centerWindow(self, 1000, 800)
         self.setWindowTitle('Select Array')
-        if colnames is None:
-            colnames = ['x', 'y', 'u(x)', 'u(y)']
+        self.colnames = colnames  # Column names that can be assigned
+        if self.colnames is None:
+            self.colnames = ['x', 'y', 'u(y)', 'u(x)']
+        self.colassignments = None
 
         self.dataset = None
         self.treeSource = ProjectTreeArrays(project=project)
         self.table = QtWidgets.QTableWidget()
         self.table.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectColumns)
         self.cmbColumn = QtWidgets.QComboBox()
-        self.cmbColumn.addItems(['Not Used'] + colnames)
+        self.cmbColumn.addItems(['Not Used'] + self.colnames)
 
         self.fig = Figure()
         self.canvas = FigureCanvas(self.fig)
@@ -615,8 +625,8 @@ class ArraySelectWidget(QtWidgets.QDialog):
         rlayout.addWidget(self.table, stretch=5)
         rlayout.addWidget(self.dlgbutton)
         layout = QtWidgets.QHBoxLayout()
-        layout.addLayout(llayout)
-        layout.addLayout(rlayout)
+        layout.addLayout(llayout, stretch=2)
+        layout.addLayout(rlayout, stretch=4)
         self.setLayout(layout)
 
         self.cmbColumn.setVisible(not self.singlecol)
@@ -627,35 +637,44 @@ class ArraySelectWidget(QtWidgets.QDialog):
         self.table.currentCellChanged.connect(self.columnselected)
         self.treeSource.loaddata.connect(self.load_data)
 
-    def _get_colassignment(self):
-        ''' Get list of variable names for each column '''
-        return [self.table.horizontalHeaderItem(i).text() if self.table.horizontalHeaderItem(i) else '' for i in range(self.table.columnCount())]
-
     def tablecolumnchanged(self):
         ''' Column assignment has changed '''
         varname = self.cmbColumn.currentText()
-        varlist = self._get_colassignment()
-        if varname == 'Not used' or varname == '':
-            self.table.setHorizontalHeaderItem(self.table.currentColumn(), QtWidgets.QTableWidgetItem(''))
+        colid = self.table.currentColumn()
+        if varname in ['Not Used', '']:
+            self.colassignments[colid] = None
         else:
-            if varname in varlist:
-                self.table.setHorizontalHeaderItem(varlist.index(varname), QtWidgets.QTableWidgetItem(''))
-            self.table.setHorizontalHeaderItem(self.table.currentColumn(), QtWidgets.QTableWidgetItem(varname))
+            if varname in self.colassignments:
+                self.colassignments[self.colassignments.index(varname)] = None
+            self.colassignments[colid] = varname
+        self.highlight_columns()
         self.updateplot()
 
+    def highlight_columns(self):
+        ''' Highlight columns that will be imported '''
+        headerlabels = []
+        for cidx in range(self.table.columnCount()):
+            if self.colassignments[cidx] and self.dataset.colnames:
+                headerlabels.append(f'{self.dataset.colnames[cidx]} → {self.colassignments[cidx]}')
+            elif self.dataset.colnames:
+                headerlabels.append(self.dataset.colnames[cidx])
+            else:
+                headerlabels.append('')
+
+            if self.colassignments[cidx]:
+                colcolor = gui_common.COLOR_SELECTED
+            else:
+                colcolor = gui_common.COLOR_OK
+            for row in range(self.table.rowCount()):
+                self.table.item(row, cidx).setBackground(colcolor)
+        self.table.setHorizontalHeaderLabels(headerlabels)
+
     def columnselected(self, row, col, prow, pcol):
         ''' Column was highlighted in table. Update combobox with variable selection. '''
         self.cmbColumn.blockSignals(True)
-        try:
-            colvar = self.table.horizontalHeaderItem(col).text()
-        except AttributeError:
-            colvar = None
-
-        self.cmbColumn.setCurrentIndex(self.cmbColumn.findText(colvar))
-        if self.cmbColumn.currentIndex() < 0:
-            self.cmbColumn.setCurrentIndex(0)  # Not used
+        name = self.colassignments[self.table.currentColumn()]
+        self.cmbColumn.setCurrentIndex(self.cmbColumn.findText(name))
         self.cmbColumn.blockSignals(False)
-
         self.updateplot()
 
     def updateplot(self):
@@ -664,8 +683,8 @@ class ArraySelectWidget(QtWidgets.QDialog):
         ax = self.fig.add_subplot(1, 1, 1)
 
         arr = self.get_array()
-        x, y = arr.x, arr.y
-        ux, uy = arr.ux, arr.uy
+        x, y = arr.get('x'), arr.get('y')
+        ux, uy = arr.get('u(x)'), arr.get('u(y)')
 
         if y is not None:
             if x is None:
@@ -701,59 +720,60 @@ class ArraySelectWidget(QtWidgets.QDialog):
     def is_datecol(self, colname):
         ''' Return True if column with name === colname is date '''
         isdate = False
-        colnames = self._get_colassignment()
-        if colname in colnames:
-            idx = colnames.index(colname)
+        if colname in self.colassignments:
+            idx = self.colassignmetns.index(colname)
             isdate = hasattr(self.dataset.data[idx][0], 'date')
         return isdate
 
     def get_array(self):
-        ''' Return nparray if singlecol, namedtuple of x, y, ux, uy if multicol '''
+        ''' Return dictionary with keys for each column name '''
         if self.dataset is None:
-            x, y, ux, uy = None, None, None, None
+            ret = {}
         elif self.singlecol:
-            item = self.table.horizontalHeaderItem(self.table.currentColumn())
-            y = self.dataset.get_column(item.text() if item else None)
-            x, ux, uy = None, None, None
+            name = self.dataset.colnames[self.table.currentColumn()]
+            y = self.dataset.get_column(name)
+            ret = {'y': y}
         else:
-            x = self._get_assigned_data('x')
-            y = self._get_assigned_data('y')
-            uy = self._get_assigned_data('u(y)')
-            ux = self._get_assigned_data('u(x)')
-        res = namedtuple('XY', ['x', 'y', 'ux', 'uy'])
-        return res(x, y, ux, uy)
-
-    def _get_assigned_data(self, colname):
-        ''' Get data for column with name == colname '''
-        assignednames = self._get_colassignment()
-        if colname in assignednames:
-            return self.dataset.data[assignednames.index(colname)]
-        else:
-            return None
+            ret = {}
+            for cidx, c in enumerate(self.colassignments):
+                if c is not None:
+                    name = self.dataset.colnames[cidx]
+                    ret[c] = self.dataset.get_column(name)
+        return ret
 
     def load_data(self, dset):
         ''' Fill table with data array
 
-            Parameters
-            ----------
-            dset: DataSet object
-                Data table to display
+            Args:
+                dset: DataSet to display
         '''
         self.table.clear()
         nrows = dset.maxrows()
         ncols = dset.ncolumns()
         self.table.setRowCount(nrows)
         self.table.setColumnCount(ncols)
+
         for col in range(ncols):
             for row in range(nrows):
                 item = QtWidgets.QTableWidgetItem(str(dset.data[col][row]))
                 item.setFlags(QtCore.Qt.ItemIsSelectable | QtCore.Qt.ItemIsEnabled)
                 self.table.setItem(row, col, item)
 
-        if self.singlecol:
-            self.table.setHorizontalHeaderLabels(dset.colnames)
-        else:
-            self.table.setHorizontalHeaderLabels(['x', 'y', 'u(y)' if dset.ncolumns() > 2 else '', 'u(x)' if dset.ncolumns() > 3 else ''])
+        self.colassignments = [None] * dset.ncolumns()
+        if not self.singlecol:
+            for cname in self.colnames:
+                if cname in dset.colnames:
+                    idx = dset.colnames.index(cname)
+                    self.colassignments[idx] = dset.colnames[idx]
+
+            if all(c is None for c in self.colassignments):
+                if 'x' in self.colnames and 'y' in self.colnames and len(self.colassignments) == 2:
+                    self.colassignments = ['x', 'y']
+                elif ('x' in self.colnames and 'y' in self.colnames and
+                      'u(y)' in self.colnames and len(self.colassignments) == 3):
+                    self.colassignments = ['x', 'y', 'u(y)']
 
         self.dataset = dset
+        self.highlight_columns()
+        self.table.resizeColumnsToContents()
         self.updateplot()
